@@ -5,7 +5,7 @@ use ross_protocol::packet::Packet;
 use crate::extractor::{Extractor, Value};
 
 #[repr(C)]
-#[cfg_attr(feature = "std", derive(serde::Serialize, serde::Deserialize))]
+#[derive(Debug)]
 pub struct EventCodeExtractor {}
 
 impl EventCodeExtractor {
@@ -14,7 +14,6 @@ impl EventCodeExtractor {
     }
 }
 
-#[cfg_attr(feature = "std", typetag::serde(name = "event_code_extractor"))]
 impl Extractor for EventCodeExtractor {
     fn extract(&self, packet: &Packet) -> Value {
         if packet.data.len() < 2 {
