@@ -1,12 +1,12 @@
 use core::fmt::Debug;
-use downcast_rs::{Downcast, impl_downcast};
+use downcast_rs::{impl_downcast, Downcast};
 
 use ross_protocol::packet::Packet;
 
 use crate::state::StateManager;
 use crate::Value;
 
-pub mod state_producer;
+pub mod state;
 
 mod bcm_change_brightness_producer;
 pub use bcm_change_brightness_producer::*;
